@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/conf-bindings.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2005. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -15,9 +15,13 @@
 #include <libtu/map.h>
 
 #include "binding.h"
-#include "extl.h"
+#include <libextl/extl.h>
 
-extern bool process_bindings(WBindmap *bindmap, StringIntMap *areamap,
-                             ExtlTab tab);
+extern bool bindmap_defbindings(WBindmap *bindmap, ExtlTab tab, bool submap);
+extern ExtlTab bindmap_getbindings(WBindmap *bindmap);
+
+extern bool ioncore_parse_keybut(const char *str, 
+                                 uint *mod_ret, uint *ksb_ret,
+                                 bool button, bool init_any);
 
 #endif /* ION_IONCORE_CONF_BINDINGS_H */
