@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/sizehint.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2005. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -15,10 +15,12 @@
 #include "common.h"
 #include "region.h"
 
-extern void correct_size(int *wp, int *hp, const XSizeHints *hints, bool min);
-extern void get_sizehints(Window win, XSizeHints *hints);
-extern void adjust_size_hints_for_managed(XSizeHints *hints, WRegion *list);
-extern int gravity_deltax(int gravity, int left, int right);
-extern int gravity_deltay(int gravity, int top, int bottom);
+extern void xsizehints_sanity_adjust(XSizeHints *hints);
+extern void xsizehints_adjust_for(XSizeHints *hints, WRegion *reg);
+extern void xsizehints_correct(const XSizeHints *hints, int *wp, int *hp, 
+                               bool min);
+
+extern int xgravity_deltax(int gravity, int left, int right);
+extern int xgravity_deltay(int gravity, int top, int bottom);
 
 #endif /* ION_IONCORE_SIZEHINT_H */
