@@ -11,8 +11,8 @@
 #define LIBTU_MAP_H
 
 typedef struct _StringIntMap{
-	const char *string;
-	int value;
+    const char *string;
+    int value;
 } StringIntMap;
 
 #define END_STRINGINTMAP {NULL, 0}
@@ -20,6 +20,8 @@ typedef struct _StringIntMap{
 /* Return the index of str in map or -1 if not found. */
 extern int stringintmap_ndx(const StringIntMap *map, const char *str);
 extern int stringintmap_value(const StringIntMap *map, const char *str,
-							  int dflt);
+                              int dflt);
+extern const char *stringintmap_key(const StringIntMap *map, 
+                                    int value, const char *dflt);
 
 #endif /* LIBTU_MAP_H */
